Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| COMERCIO DE COMBUSTIVEIS AIMORE
CNPJ: 91.979.286/0001-54 Inscrição Estadual: 1090259503
Avenida Roraima, 002, Camobi, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 46267 Série: 1 Data de Emissão: 11/09/2019 17:55:58
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0991 9792 8600 0154 6500 1000 0462 6710 0047 7172
Protocolo de Autorização: 143191245640020
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
1 | GASOLINA COMUM | 40,009 | LT | 4,499 | 180,00
Valor total R$ | 180,00
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:31